# abqpy 2022

[![pytest](https://github.com/haiiliin/abqpy/actions/workflows/pytest.yml/badge.svg)](https://github.com/haiiliin/abqpy/actions/workflows/pytest.yml)
[![docs-test](https://github.com/haiiliin/abqpy/actions/workflows/docs-test.yml/badge.svg)](https://github.com/haiiliin/abqpy/actions/workflows/docs-test.yml)

其它语言版本: [English](README.md), [简体中文](README-zh-cn.md).

Abaqus/Python 脚本的类型提示

`abqpy` 是一个 Python 包，为 Abaqus 的 Python 脚本提供类型提示，您可以使用它方便地编写 Abaqus Python 脚本。 
它还提供了一些简单的 API 来执行 Abaqus 命令，以便您可以运行 Python 脚本来创建模型、
提交作业并提取输出数据，即使不打开 Abaqus/CAE。

- 主页: https://abqpy.com
- GitHub 仓库: https://github.com/haiiliin/abqpy
- PyPI: https://pypi.org/project/abqpy
- Anaconda: https://anaconda.org/haiiliin/abqpy
- Read the Docs: https://readthedocs.org/projects/abqpy
- 中文文档: https://docs.abqpy.com/zh_CN/latest
- 错误报告: https://github.com/haiiliin/abqpy/issues

## 欢迎拉取合并请求

由于`abqpy`是从 Abaqus 官方文档中重构出来的，很多文档字符串的格式还不完善，比如
数学方程，对象的属性，由于我的时间有限，这些东西还没有完成，如果有人愿意做出任何贡献，
请随时创建您的拉取请求。

请参阅 [CONTRIBUTING](https://github.com/haiiliin/abqpy/blob/main/.github/CONTRIBUTING.md) 了解贡献指南.
